**************
Reporting bugs
**************

File bug reports or feature requests, and make contributions
(e.g. code patches), by submitting a "ticket" on the Trac pages:

- Numpy Trac: http://scipy.org/scipy/numpy

Because of spam abuse, you must create an account on our Trac in order
to submit a ticket, then click on the "New Ticket" tab that only
appears when you have logged in. Please give as much information as
you can in the ticket. It is extremely useful if you can supply a
small self-contained code snippet that reproduces the problem. Also
specify the component, the version you are referring to and the
milestone.

Report bugs to the appropriate Trac instance (there is one for NumPy
and a different one for SciPy). There are also read-only mailing lists
for tracking the status of your bug ticket.

More information can be found on the http://scipy.org/Developer_Zone
website.
